
package org.apidesign.apifest08.currency;

import java.util.Currency;

/**
 * Desription of currency. 
 * 
 * Java has similar class {@link java.util.Currency}, but original class is not flexible
 * enough, we use our own implementation of currency.
 *
 * @author arnostvalicek
 */
public class ConvertorCurrency {

    private Currency currency;

    private void setJavaCurrency(Currency javaCurrency) {
        this.currency = javaCurrency;
    }

    /**
     * Static method providing instance of <code>ConvertorCurrency</code> base of currency code.
     * 
     * @param currencyCode Code of required currency.
     * @return Returns required <code>ConvertorCurrency</code>
     */
    public static ConvertorCurrency getInstance(String currencyCode) {
        ConvertorCurrency convertorCurrency = new ConvertorCurrency();
        convertorCurrency.setJavaCurrency(Currency.getInstance(currencyCode));
        return convertorCurrency;
    }

    /**
     * Gets the default number of fraction digits used with this currency. For example, the default number of fraction digits for the Euro is 2, while for the Japanese Yen it's 0.
     * @return Returns the default number of fraction digits used with this currency.
     */
    public int getDefaultFractionDigits() {
        return currency.getDefaultFractionDigits();
    }

    @Override
    public String toString() {
        return getClass() + " based on " + (currency != null ? currency.toString() : "NO-BASE-CURRENCY");
    }
}
